import React, { useState } from 'react';
import { getStartOfDayDate } from '../dateUtils';
export var useTopContributors = function (client, tsDataName, limit) {
    var _a = useState(true), loading = _a[0], setLoading = _a[1];
    var _b = React.useState(false), error = _b[0], setError = _b[1];
    var _c = React.useState(), contribs = _c[0], setContribs = _c[1];
    var currentDate = Date.now();
    var todayMidnight = getStartOfDayDate(currentDate);
    React.useEffect(function () {
        var fetchTimeseries = function () {
            setError(false);
            setLoading(true);
            return client.lucene("ogit\\/_type: \"ogit/Timeseries\" AND \\/DataName: \"" + tsDataName + "\"", { limit: 1 });
        };
        var fetchContributors = function (tsId) {
            return client.streamts(tsId, {
                from: todayMidnight,
                limit: 1,
            });
        };
        var sortTopContribs = function (contributors) {
            return Object.entries(contributors)
                .sort(function (a, b) { return b[1] - a[1]; })
                .slice(0, limit);
        };
        fetchTimeseries()
            .then(function (timeseries) {
            if (timeseries.length === 0) {
                // we don't need the rest of chain
                return Promise.reject([]);
            }
            var tsId = timeseries[0]['ogit/_id'];
            return fetchContributors(tsId);
        })
            .then(function (contributors) {
            var parsedContribs = contributors.length > 0 ? JSON.parse(contributors[0].value) : {};
            var topContribs = sortTopContribs(parsedContribs);
            return Promise.all(topContribs.map(function (contributor) {
                return Promise.all([client.get(contributor[0]), contributor[1]]);
            }));
        })
            .then(function (accounts) {
            var finalContribs = accounts.map(function (account) { return [
                account[0]['ogit/name'],
                account[1],
            ]; });
            setContribs(finalContribs);
            setLoading(false);
            return finalContribs;
        })
            .catch(function (rejectedValue) {
            setLoading(false);
            if (rejectedValue instanceof Error) {
                console.error('Top Contributors:', rejectedValue);
                setError(true);
            }
            else {
                setContribs(rejectedValue);
            }
        });
    }, [client, todayMidnight, limit, tsDataName]);
    return { loading: loading, error: error, contributors: contribs };
};
